@@ -16,6 +16,8 @@ def get_default_lido_abi_path(chain_name: str) -> str:
         return os.path.join(script_dir, "abi/mainnet/Lido.json")
     elif chain_name == "goerli":
         return os.path.join(script_dir, "abi/goerli/Lido.json")
+    elif chain_name == "ropsten":
+        return os.path.join(script_dir, "abi/ropsten/Lido.json")
     else:
         raise Exception("Unable to load Lido ABI for network")
 
@@ -25,5 +27,7 @@ def get_default_operators_abi_path(chain_name: str) -> str:
         return os.path.join(script_dir, "abi/mainnet/NodeOperatorsRegistry.json")
     elif chain_name == "goerli":
         return os.path.join(script_dir, "abi/goerli/NodeOperatorsRegistry.json")
+    elif chain_name == "ropsten":
+        return os.path.join(script_dir, "abi/ropsten/NodeOperatorsRegistry.json")
     else:
-        raise Exception("Unable to load NodeOperatorsRegistry ABI for network")
\ No newline at end of file
+        raise Exception("Unable to load NodeOperatorsRegistry ABI for network")
